@@ -17,8 +17,8 @@ from neosctl.util import upsert_config
 app = typer.Typer()
 
 
-def auth_url(gateway_api_url: str) -> str:
-    return "{}".format(gateway_api_url.rstrip("/"))
+def auth_url(iam_api_url: str) -> str:
+    return "{}".format(iam_api_url.rstrip("/"))
 
 
 def _check_refresh_token_exists(ctx: typer.Context):
@@ -98,7 +98,7 @@ def login(
 
     r = util.post(
         ctx,
-        "{auth_url}/login".format(auth_url=auth_url(ctx.obj.get_gateway_api_url())),
+        "{auth_url}/login".format(auth_url=auth_url(ctx.obj.get_iam_api_url())),
         json={"user": ctx.obj.profile.user, "password": password},
     )
 
@@ -123,7 +123,7 @@ def logout(ctx: typer.Context):
 
     r = util.post(
         ctx,
-        "{auth_url}/logout".format(auth_url=auth_url(ctx.obj.get_gateway_api_url())),
+        "{auth_url}/logout".format(auth_url=auth_url(ctx.obj.get_iam_api_url())),
         json={"refresh_token": ctx.obj.profile.refresh_token},
     )
 
@@ -144,7 +144,7 @@ def refresh_token(ctx: typer.Context):
 
     r = util.post(
         ctx,
-        "{auth_url}/refresh".format(auth_url=auth_url(ctx.obj.get_gateway_api_url())),
+        "{auth_url}/refresh".format(auth_url=auth_url(ctx.obj.get_iam_api_url())),
         json={"refresh_token": ctx.obj.profile.refresh_token},
     )
 
