@@ -121,6 +121,11 @@ def delete_data(
 def delete(
     ctx: typer.Context,
     name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+    force: bool = typer.Option(
+        False,
+        "--force",
+        help="Force remove even if attached spark application is still running.",
+    ),
 ):
     """Delete a data product.
     """
@@ -129,6 +134,7 @@ def delete(
         return util.delete(
             ctx,
             "{dp_url}/{name}".format(dp_url=product_url(ctx), name=name),
+            params={"force": force},
         )
 
     r = _request(ctx)
