@@ -50,17 +50,112 @@ def add_job(
 
 
 @app.command()
-def job_status(
+def generate_job(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+    json_filepath: str = typer.Option(..., "--json-filepath", "-f"),
+    dry_run: bool = typer.Option(
+        False,
+        "--dry-run",
+        help="Generate spark code, but don't save the output.",
+    ),
+    reassign: bool = typer.Option(
+        False,
+        "--reassign",
+        help="Generate spark code and replace existing spark job.",
+    ),
+):
+    """Generate and assign a spark job.
+
+    Generate a spark job from source/transformations configuration for a data product. This will result in a
+    one off run of the spark job but no output.
+    """
+    @ensure_login
+    def _request(ctx: typer.Context, data: typing.Dict) -> httpx.Response:
+        return util.post(
+            ctx,
+            "{spark_url}/generate".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            json=data,
+        )
+
+    fp = util.get_file_location(json_filepath)
+    data = util.load_json_file(fp, "builder")
+    data["preview"] = dry_run
+    data["reassign"] = reassign
+
+    r = _request(ctx, data)
+
+    process_response(r)
+
+
+@app.command()
+def job_history(
     ctx: typer.Context,
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
 ):
-    """Get current status of a spark job.
+    """Get history of spark applications.
     """
+    @ensure_login
+    def _request(ctx: typer.Context) -> httpx.Response:
+        return util.get(
+            ctx,
+            "{spark_url}/history".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+        )
+    r = _request(ctx)
+
+    process_response(r)
+
+
+@app.command()
+def run_history(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+    suffix: str = typer.Option(None, "--suffix", "-s"),
+):
+    """Get history of spark application runs.
+    """
+    @ensure_login
+    def _request(ctx: typer.Context) -> httpx.Response:
+        return util.get(
+            ctx,
+            "{spark_url}/history/{suffix}/run".format(
+                spark_url=spark_url(product_name, ctx.obj.gateway_api_url),
+                suffix=suffix,
+            ),
+        )
+    r = _request(ctx)
+
+    process_response(r)
+
+
+@app.command()
+def job_status(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+    suffix: str = typer.Option(None, "--suffix", "-s"),
+    run: str = typer.Option(None, "--run", "-r"),
+):
+    """Get status of a spark job.
+
+    Defaults to current application status, previous application status or a
+    specific scheduled run can be requested.
+    """
+
+    params = {
+        k: v
+        for k, v in {
+            "suffix": suffix,
+            "run": run,
+        }.items()
+        if v is not None
+    }
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
             ctx,
             "{spark_url}".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            params=params,
         )
     r = _request(ctx)
 
@@ -75,14 +170,29 @@ def render_logs(payload: typing.Dict):
 def job_logs(
     ctx: typer.Context,
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+    suffix: str = typer.Option(None, "--suffix", "-s"),
+    run: str = typer.Option(None, "--run", "-r"),
 ):
     """Get logs for a spark job.
+
+    Defaults to current application logs, previous application logs or a
+    specific scheduled run can be requested.
     """
+    params = {
+        k: v
+        for k, v in {
+            "suffix": suffix,
+            "run": run,
+        }.items()
+        if v is not None
+    }
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
             ctx,
             "{spark_url}/log".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            params=params,
         )
     r = _request(ctx)
 
@@ -127,6 +237,11 @@ def update_job(
 def remove_job(
     ctx: typer.Context,
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+    force: bool = typer.Option(
+        False,
+        "--force",
+        help="Force remove even if application is still running.",
+    ),
 ):
     """Remove assigned spark job.
     """
@@ -135,6 +250,7 @@ def remove_job(
         return util.delete(
             ctx,
             spark_url(product_name, ctx.obj.gateway_api_url),
+            params={"force": force},
         )
 
     r = _request(ctx)
@@ -229,6 +345,50 @@ def schedule_job(
     process_response(r)
 
 
+@app.command()
+def reschedule_job(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+    schedule: str = typer.Option(..., "--schedule", "-s", help='Schedule in crontab format (e.g. "* * * * *")'),
+):
+    """Reschedule an assigned spark job.
+
+    Update existing scheduled spark job run schedule.
+    """
+    @ensure_login
+    def _request(ctx: typer.Context) -> httpx.Response:
+        return util.put(
+            ctx,
+            "{spark_url}/scheduled".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            json={
+                "cron_expression": schedule,
+            },
+        )
+
+    r = _request(ctx)
+    process_response(r)
+
+
+@app.command()
+def unschedule_job(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+):
+    """Unschedule a scheduled spark job.
+
+    Remove existing scheduled spark job.
+    """
+    @ensure_login
+    def _request(ctx: typer.Context) -> httpx.Response:
+        return util.delete(
+            ctx,
+            "{spark_url}/scheduled".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+        )
+
+    r = _request(ctx)
+    process_response(r)
+
+
 @secret_app.command()
 def add(
     ctx: typer.Context,
